@@ -15,10 +15,11 @@
 
 from math import exp, sin, cos
 
-def kotanchek(data):
-    """Kotanchek benchmark function.
 
-    .. list-table:: 
+def kotanchek(data):
+    r"""Kotanchek benchmark function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -29,10 +30,11 @@ def kotanchek(data):
     """
     return exp(-(data[0] - 1)**2) / (3.2 + (data[1] - 2.5)**2)
 
-def salustowicz_1d(data):
-    """Salustowicz benchmark function.
 
-    .. list-table:: 
+def salustowicz_1d(data):
+    r"""Salustowicz benchmark function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -43,10 +45,11 @@ def salustowicz_1d(data):
     """
     return exp(-data[0]) * data[0]**3 * cos(data[0]) * sin(data[0]) * (cos(data[0]) * sin(data[0])**2 - 1)
 
-def salustowicz_2d(data):
-    """Salustowicz benchmark function.
 
-    .. list-table:: 
+def salustowicz_2d(data):
+    r"""Salustowicz benchmark function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -57,10 +60,11 @@ def salustowicz_2d(data):
     """
     return exp(-data[0]) * data[0]**3 * cos(data[0]) * sin(data[0]) * (cos(data[0]) * sin(data[0])**2 - 1) * (data[1] - 5)
 
-def unwrapped_ball(data):
-    """Unwrapped ball benchmark function.
 
-    .. list-table:: 
+def unwrapped_ball(data):
+    r"""Unwrapped ball benchmark function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -71,10 +75,11 @@ def unwrapped_ball(data):
     """
     return 10. / (5. + sum((d - 3)**2 for d in data))
 
-def rational_polynomial(data):
-    """Rational polynomial ball benchmark function.
 
-    .. list-table:: 
+def rational_polynomial(data):
+    r"""Rational polynomial ball benchmark function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -85,10 +90,11 @@ def rational_polynomial(data):
     """
     return 30. * (data[0] - 1) * (data[2] - 1) / (data[1]**2 * (data[0] - 10))
 
-def sin_cos(data):
-    """Sine cosine benchmark function.
 
-    .. list-table:: 
+def sin_cos(data):
+    r"""Sine cosine benchmark function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -99,10 +105,11 @@ def sin_cos(data):
     """
     6 * sin(data[0]) * cos(data[1])
 
-def ripple(data):
-    """Ripple benchmark function.
 
-    .. list-table:: 
+def ripple(data):
+    r"""Ripple benchmark function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
@@ -113,10 +120,11 @@ def ripple(data):
     """
     return (data[0] - 3) * (data[1] - 3) + 2 * sin((data[0] - 4) * (data[1] - 4))
 
-def rational_polynomial2(data):
-    """Rational polynomial benchmark function.
 
-    .. list-table:: 
+def rational_polynomial2(data):
+    r"""Rational polynomial benchmark function.
+
+    .. list-table::
        :widths: 10 50
        :stub-columns: 1
 
