@@ -14,7 +14,7 @@
 #    License along with DEAP. If not, see <http://www.gnu.org/licenses/>.
 
 """
-Re-implementation of the `Moving Peaks Benchmark 
+Re-implementation of the `Moving Peaks Benchmark
 <http://people.aifb.kit.edu/jbr/MovPeaks/>`_ by Jurgen Branke. With the
 addition of the fluctuating number of peaks presented in *du Plessis and
 Engelbrecht, 2013, Self-Adaptive Environment with Fluctuating Number of
@@ -30,8 +30,9 @@ try:
 except:
     from collections import Sequence
 
+
 def cone(individual, position, height, width):
-    """The cone peak function to be used with scenario 2 and 3.
+    r"""The cone peak function to be used with scenario 2 and 3.
 
     :math:`f(\mathbf{x}) = h - w \sqrt{\sum_{i=1}^N (x_i - p_i)^2}`
 
@@ -41,14 +42,16 @@ def cone(individual, position, height, width):
         value += (x - p)**2
     return height - width * math.sqrt(value)
 
+
 def sphere(individual, position, height, width):
     value = 0.0
     for x, p in zip(individual, position):
         value += (x - p)**2
     return height * value
 
+
 def function1(individual, position, height, width):
-    """The function1 peak function to be used with scenario 1.
+    r"""The function1 peak function to be used with scenario 1.
 
     :math:`f(\mathbf{x}) = \\frac{h}{1 + w \sqrt{\sum_{i=1}^N (x_i - p_i)^2}}`
 
@@ -58,6 +61,7 @@ def function1(individual, position, height, width):
         value += (x - p)**2
     return height / (1 + width * value)
 
+
 class MovingPeaks:
     """The Moving Peaks Benchmark is a fitness function changing over time. It
     consists of a number of peaks, changing in height, width and location. The
@@ -161,7 +165,6 @@ class MovingPeaks:
         else:
             self.peaks_height = [self.random.uniform(self.min_height, self.max_height) for _ in range(npeaks)]
 
-
         if uniform_width != 0:
             self.peaks_width = [uniform_width for _ in range(npeaks)]
         else:
@@ -194,7 +197,7 @@ class MovingPeaks:
         """Returns all visible maximums value and position sorted with the
         global maximum first.
         """
-        # The maximums are at the peaks position but might be swallowed by 
+        # The maximums are at the peaks position but might be swallowed by
         # other peaks
         maximums = list()
         for func, pos, height, width in zip(self.peaks_function,
@@ -284,7 +287,7 @@ class MovingPeaks:
             shift_length = sum(s**2 for s in shift)
             shift_length = self.move_severity / math.sqrt(shift_length) if shift_length > 0 else 0
 
-            shift = [shift_length * (1.0 - self.lambda_) * s \
+            shift = [shift_length * (1.0 - self.lambda_) * s
                      + self.lambda_ * c for s, c in zip(shift, self.last_change_vector[i])]
 
             shift_length = sum(s**2 for s in shift)
@@ -331,8 +334,9 @@ class MovingPeaks:
 
         self._optimum = None
 
-SCENARIO_1 = {"pfunc" : function1,
-              "npeaks" : 5,
+
+SCENARIO_1 = {"pfunc": function1,
+              "npeaks": 5,
               "bfunc": None,
               "min_coord": 0.0,
               "max_coord": 100.0,
@@ -348,9 +352,9 @@ SCENARIO_1 = {"pfunc" : function1,
               "width_severity": 0.01,
               "period": 5000}
 
-SCENARIO_2 = {"pfunc" : cone,
-              "npeaks" : 10,
-              "bfunc" : None,
+SCENARIO_2 = {"pfunc": cone,
+              "npeaks": 10,
+              "bfunc": None,
               "min_coord": 0.0,
               "max_coord": 100.0,
               "min_height": 30.0,
@@ -365,9 +369,9 @@ SCENARIO_2 = {"pfunc" : cone,
               "width_severity": 1.0,
               "period": 5000}
 
-SCENARIO_3 = {"pfunc" : cone,
-              "npeaks" : 50,
-              "bfunc" : lambda x: 10,
+SCENARIO_3 = {"pfunc": cone,
+              "npeaks": 50,
+              "bfunc": lambda x: 10,
               "min_coord": 0.0,
               "max_coord": 100.0,
               "min_height": 30.0,
@@ -382,6 +386,7 @@ SCENARIO_3 = {"pfunc" : cone,
               "width_severity": 0.5,
               "period": 1000}
 
+
 def diversity(population):
     nind = len(population)
     ndim = len(population[0])
@@ -391,8 +396,9 @@ def diversity(population):
     d = [di / nind for di in d]
     return math.sqrt(sum((di - xi)**2 for x in population for di, xi in zip(d, x)))
 
+
 if __name__ == "__main__":
-    mpb = MovingPeaks(dim=2, npeaks=[1,1,10], number_severity=0.1)
+    mpb = MovingPeaks(dim=2, npeaks=[1, 1, 10], number_severity=0.1)
     print(mpb.maximums())
     mpb.changePeaks()
     print(mpb.maximums())
