@@ -11,6 +11,7 @@ import numpy
 # Non-Dominated Sorting   (NSGA-II)  #
 ######################################
 
+
 def selNSGA2(individuals, k, nd='standard'):
     """Apply NSGA-II selection operator on the *individuals*. Usually, the
     size of *individuals* will be larger than *k* because any individual
@@ -115,6 +116,7 @@ def sortNondominated(individuals, k, first_front_only=False):
 
     return fronts
 
+
 def assignCrowdingDist(individuals):
     """Assign a crowding distance to each individual's fitness. The
     crowding distance can be retrieve via the :attr:`crowding_dist`
@@ -141,26 +143,27 @@ def assignCrowdingDist(individuals):
     for i, dist in enumerate(distances):
         individuals[i].fitness.crowding_dist = dist
 
+
 def selTournamentDCD(individuals, k):
     """Tournament selection based on dominance (D) between two individuals, if
     the two individuals do not interdominate the selection is made
     based on crowding distance (CD). The *individuals* sequence length has to
-    be a multiple of 4 only if k is equal to the length of individuals. 
-    Starting from the beginning of the selected individuals, two consecutive 
-    individuals will be different (assuming all individuals in the input list 
-    are unique). Each individual from the input list won't be selected more 
+    be a multiple of 4 only if k is equal to the length of individuals.
+    Starting from the beginning of the selected individuals, two consecutive
+    individuals will be different (assuming all individuals in the input list
+    are unique). Each individual from the input list won't be selected more
     than twice.
 
     This selection requires the individuals to have a :attr:`crowding_dist`
     attribute, which can be set by the :func:`assignCrowdingDist` function.
 
     :param individuals: A list of individuals to select from.
-    :param k: The number of individuals to select. Must be less than or equal 
+    :param k: The number of individuals to select. Must be less than or equal
               to len(individuals).
     :returns: A list of selected individuals.
     """
 
-    if k > len(individuals): 
+    if k > len(individuals):
         raise ValueError("selTournamentDCD: k must be less than or equal to individuals length")
 
     if k == len(individuals) and k % 4 != 0:
@@ -186,9 +189,9 @@ def selTournamentDCD(individuals, k):
 
     chosen = []
     for i in range(0, k, 4):
-        chosen.append(tourn(individuals_1[i],   individuals_1[i+1]))
+        chosen.append(tourn(individuals_1[i], individuals_1[i+1]))
         chosen.append(tourn(individuals_1[i+2], individuals_1[i+3]))
-        chosen.append(tourn(individuals_2[i],   individuals_2[i+1]))
+        chosen.append(tourn(individuals_2[i], individuals_2[i+1]))
         chosen.append(tourn(individuals_2[i+2], individuals_2[i+3]))
 
     return chosen
@@ -197,11 +200,13 @@ def selTournamentDCD(individuals, k):
 # Generalized Reduced runtime ND sort #
 #######################################
 
+
 def identity(obj):
     """Returns directly the argument *obj*.
     """
     return obj
 
+
 def isDominated(wvalues1, wvalues2):
     """Returns whether or not *wvalues2* dominates *wvalues1*.
 
@@ -218,6 +223,7 @@ def isDominated(wvalues1, wvalues2):
             not_equal = True
     return not_equal
 
+
 def median(seq, key=identity):
     """Returns the median of *seq* - the numeric value separating the higher
     half of a sample from the lower half. If there is an even number of
@@ -230,6 +236,7 @@ def median(seq, key=identity):
     else:
         return (key(sseq[(length - 1) // 2]) + key(sseq[length // 2])) / 2.0
 
+
 def sortLogNondominated(individuals, k, first_front_only=False):
     """Sort *individuals* in pareto non-dominated fronts using the Generalized
     Reduced Run-Time Complexity Non-Dominated Sorting Algorithm presented by
@@ -242,12 +249,12 @@ def sortLogNondominated(individuals, k, first_front_only=False):
     if k == 0:
         return []
 
-    #Separate individuals according to unique fitnesses
+    # Separate individuals according to unique fitnesses
     unique_fits = defaultdict(list)
     for i, ind in enumerate(individuals):
         unique_fits[ind.fitness.wvalues].append(ind)
 
-    #Launch the sorting algorithm
+    # Launch the sorting algorithm
     obj = len(individuals[0].fitness.wvalues)-1
     fitnesses = list(unique_fits.keys())
     front = dict.fromkeys(fitnesses, 0)
@@ -256,7 +263,7 @@ def sortLogNondominated(individuals, k, first_front_only=False):
     fitnesses.sort(reverse=True)
     sortNDHelperA(fitnesses, obj, front)
 
-    #Extract individuals from front list here
+    # Extract individuals from front list here
     nbfronts = max(front.values())+1
     pareto_fronts = [[] for i in range(nbfronts)]
     for fit in fitnesses:
@@ -274,6 +281,7 @@ def sortLogNondominated(individuals, k, first_front_only=False):
     else:
         return pareto_fronts[0]
 
+
 def sortNDHelperA(fitnesses, obj, front):
     """Create a non-dominated sorting of S on the first M objectives"""
     if len(fitnesses) < 2:
@@ -286,7 +294,7 @@ def sortNDHelperA(fitnesses, obj, front):
     elif obj == 1:
         sweepA(fitnesses, front)
     elif len(frozenset(map(itemgetter(obj), fitnesses))) == 1:
-        #All individuals for objective M are equal: go to objective M-1
+        # All individuals for objective M are equal: go to objective M-1
         sortNDHelperA(fitnesses, obj-1, front)
     else:
         # More than two individuals, split list and then apply recursion
@@ -295,6 +303,7 @@ def sortNDHelperA(fitnesses, obj, front):
         sortNDHelperB(best, worst, obj-1, front)
         sortNDHelperA(worst, obj, front)
 
+
 def splitA(fitnesses, obj):
     """Partition the set of fitnesses in two according to the median of
     the objective index *obj*. The values equal to the median are put in
@@ -323,6 +332,7 @@ def splitA(fitnesses, obj):
     else:
         return best_b, worst_b
 
+
 def sweepA(fitnesses, front):
     """Update rank number associated to the fitnesses according
     to the first two objectives using a geometric sweep procedure.
@@ -342,6 +352,7 @@ def sweepA(fitnesses, front):
         stairs.insert(idx, -fit[1])
         fstairs.insert(idx, fit)
 
+
 def sortNDHelperB(best, worst, obj, front):
     """Assign front numbers to the solutions in H according to the solutions
     in L. The solutions in L are assumed to have correct front numbers and the
@@ -349,10 +360,10 @@ def sortNDHelperB(best, worst, obj, front):
     happen after sortNDHelperB is called."""
     key = itemgetter(obj)
     if len(worst) == 0 or len(best) == 0:
-        #One of the lists is empty: nothing to do
+        # One of the lists is empty: nothing to do
         return
     elif len(best) == 1 or len(worst) == 1:
-        #One of the lists has one individual: compare directly
+        # One of the lists has one individual: compare directly
         for hi in worst:
             for li in best:
                 if isDominated(hi[:obj+1], li[:obj+1]) or hi[:obj+1] == li[:obj+1]:
@@ -360,10 +371,10 @@ def sortNDHelperB(best, worst, obj, front):
     elif obj == 1:
         sweepB(best, worst, front)
     elif key(min(best, key=key)) >= key(max(worst, key=key)):
-        #All individuals from L dominate H for objective M:
-        #Also supports the case where every individuals in L and H
-        #has the same value for the current objective
-        #Skip to objective M-1
+        # All individuals from L dominate H for objective M:
+        # Also supports the case where every individuals in L and H
+        # has the same value for the current objective
+        # Skip to objective M-1
         sortNDHelperB(best, worst, obj-1, front)
     elif key(max(best, key=key)) >= key(min(worst, key=key)):
         best1, best2, worst1, worst2 = splitB(best, worst, obj)
@@ -371,6 +382,7 @@ def sortNDHelperB(best, worst, obj, front):
         sortNDHelperB(best1, worst2, obj-1, front)
         sortNDHelperB(best2, worst2, obj, front)
 
+
 def splitB(best, worst, obj):
     """Split both best individual and worst sets of fitnesses according
     to the median of objective *obj* computed on the set containing the
@@ -410,6 +422,7 @@ def splitB(best, worst, obj):
     else:
         return best1_b, best2_b, worst1_b, worst2_b
 
+
 def sweepB(best, worst, front):
     """Adjust the rank number of the worst fitnesses according to
     the best fitnesses on the first two objectives using a sweep
@@ -443,6 +456,7 @@ def sweepB(best, worst, front):
 # Non-Dominated Sorting  (NSGA-III)  #
 ######################################
 
+
 NSGA3Memory = namedtuple("NSGA3Memory", ["best_point", "worst_point", "extreme_points"])
 
 
@@ -607,7 +621,7 @@ def associate_to_niche(fitnesses, reference_points, best_point, intercepts):
     """Associates individuals to reference points and calculates niche number.
     Corresponds to Algorithm 3 of Deb & Jain (2014)."""
     # Normalize by ideal point and intercepts
-    fn = (fitnesses - best_point) / (intercepts - best_point)
+    fn = (fitnesses - best_point) / (intercepts - best_point + numpy.finfo(float).eps)
 
     # Create distance matrix
     fn = numpy.repeat(numpy.expand_dims(fn, axis=1), len(reference_points), axis=1)
@@ -734,7 +748,7 @@ def selSPEA2(individuals, k):
                 dist = 0.0
                 for l in range(L):
                     val = individuals[i].fitness.values[l] - \
-                          individuals[j].fitness.values[l]
+                        individuals[j].fitness.values[l]
                     dist += val * val
                 distances[j] = dist
             kth_dist = _randomizedSelect(distances, 0, N - 1, K)
@@ -744,7 +758,7 @@ def selSPEA2(individuals, k):
         next_indices = [(fits[i], i) for i in range(N)
                         if not i in chosen_indices]
         next_indices.sort()
-        #print next_indices
+        # print next_indices
         chosen_indices += [i for _, i in next_indices[:k - len(chosen_indices)]]
 
     elif len(chosen_indices) > k:   # The archive is too large
@@ -756,7 +770,7 @@ def selSPEA2(individuals, k):
                 dist = 0.0
                 for l in range(L):
                     val = individuals[chosen_indices[i]].fitness.values[l] - \
-                          individuals[chosen_indices[j]].fitness.values[l]
+                        individuals[chosen_indices[j]].fitness.values[l]
                     dist += val * val
                 distances[i][j] = dist
                 distances[j][i] = dist
@@ -806,6 +820,7 @@ def selSPEA2(individuals, k):
 
     return [individuals[i] for i in chosen_indices]
 
+
 def _randomizedSelect(array, begin, end, i):
     """Allows to select the ith smallest element from array without sorting it.
     Runtime is expected to be O(n).
@@ -819,11 +834,13 @@ def _randomizedSelect(array, begin, end, i):
     else:
         return _randomizedSelect(array, q + 1, end, i - k)
 
+
 def _randomizedPartition(array, begin, end):
     i = random.randint(begin, end)
     array[begin], array[i] = array[i], array[begin]
     return _partition(array, begin, end)
 
+
 def _partition(array, begin, end):
     x = array[begin]
     i = begin - 1
