@@ -1,5 +1,3 @@
-import pickle
-
 from bisect import bisect_right
 from collections import defaultdict
 from copy import deepcopy
@@ -13,6 +11,7 @@ def identity(obj):
     """
     return obj
 
+
 class History(object):
     """The :class:`History` class helps to build a genealogy of all the
     individuals produced in the evolution. It contains two attributes,
@@ -51,7 +50,7 @@ class History(object):
     Using NetworkX in combination with `pygraphviz
     <http://networkx.lanl.gov/pygraphviz/>`_ (dot layout) this amazing
     genealogy tree can be obtained from the OneMax example with a population
-    size of 20 and 5 generations, where the color of the nodes indicate there
+    size of 20 and 5 generations, where the color of the nodes indicate their
     fitness, blue is low and red is high.
 
     .. image:: /_images/genealogy.png
@@ -131,6 +130,7 @@ class History(object):
         """
         gtree = {}
         visited = set()     # Adds memory to the breadth first search
+
         def genealogy(index, depth):
             if index not in self.genealogy_tree:
                 return
@@ -146,6 +146,7 @@ class History(object):
         genealogy(individual.history_index, 0)
         return gtree
 
+
 class Statistics(object):
     """Object that compiles statistics on a list of arbitrary objects.
     When created the statistics object receives a *key* argument that
@@ -204,6 +205,7 @@ class Statistics(object):
             entry[key] = func(values)
         return entry
 
+
 class MultiStatistics(dict):
     """Dictionary of :class:`Statistics` object allowing to compute
     statistics on multiple keys using a single call to :meth:`compile`. It
@@ -253,6 +255,7 @@ class MultiStatistics(dict):
         for stats in self.values():
             stats.register(name, function, *args, **kargs)
 
+
 class Logbook(list):
     """Evolution records as a chronological list of dictionaries.
 
@@ -440,7 +443,7 @@ class Logbook(list):
             str_line = []
             for j, name in enumerate(columns):
                 if name in chapters_txt:
-                    column = chapters_txt[name][i+offsets[name]]
+                    column = chapters_txt[name][i + offsets[name]]
                 else:
                     value = line.get(name, "")
                     string = "{0:n}" if isinstance(value, float) else "{0}"
@@ -462,9 +465,9 @@ class Logbook(list):
                     for i in range(blanks):
                         header[i].append(" " * length)
                     header[blanks].append(name.center(length))
-                    header[blanks+1].append("-" * length)
+                    header[blanks + 1].append("-" * length)
                     for i in range(offsets[name]):
-                        header[blanks+2+i].append(chapters_txt[name][i])
+                        header[blanks + 2 + i].append(chapters_txt[name][i])
                 else:
                     length = max(len(line[j].expandtabs()) for line in str_matrix)
                     for line in header[:-1]:
@@ -519,7 +522,7 @@ class HallOfFame(object):
                            update the hall of fame with.
         """
         for ind in population:
-            if len(self) == 0 and self.maxsize !=0:
+            if len(self) == 0 and self.maxsize != 0:
                 # Working on an empty hall of fame is problematic for the
                 # "for else"
                 self.insert(population[0])
@@ -634,13 +637,12 @@ class ParetoFront(HallOfFame):
             if not is_dominated and not has_twin:
                 self.insert(ind)
 
+
 __all__ = ['HallOfFame', 'ParetoFront', 'History', 'Statistics', 'MultiStatistics', 'Logbook']
 
 if __name__ == "__main__":
     import doctest
-    from operator import itemgetter
 
-    import numpy
     doctest.run_docstring_examples(Statistics, globals())
     doctest.run_docstring_examples(Statistics.register, globals())
     doctest.run_docstring_examples(Statistics.compile, globals())
